FUNCTION_DESCRIPTION
set_bandind_matrix(
bandnames,
bandsel,
indexes_bandnames,
indexes_bandsel,
indexes_formula,
quality_bandnames,
quality_bandsel,
quality_source
)matrix containing info on which bands are needed for computing
each available QI or SI
names of all layers available for the product being processed
character array Original MODIS layers to be processed.
You can get a list of available layers for a given product
using function MODIStsp_get_prodlayers (e.g., MODIStsp_get_prodlayers("M*D13Q1")$bandnames),
Default: NULL
names of all indexes available for the product being processed
character arraySpectral Indexes to be computed starting from reflectance bands.
You can get a list of available quality layers for a given product
using function MODIStsp_get_prodlayers (e.g., MODIStsp_get_prodlayers("M*D13Q1")$indexes_bandnames),
Default: NULL
formulas of all indexes available for the product being processed
names of all quality indicators available for the product being processed
character array Quality Indicators to be computed starting from
bit fields of original MODIS layers. You can get a list of available quality layers for a given product
using function MODIStsp_get_prodlayers (e.g., MODIStsp_get_prodlayers("M*D13Q1")$quality_bandnames),
Default: NULL
sources of data (original layers) of all quality indicators available for the product being processed
Lorenzo Busetto, phD (2017)