Internal function dealing with download of MODIS hdfs from http remote server for a given date.
MODIStsp_download(
modislist,
out_folder_mod,
download_server,
http,
n_retries,
use_aria,
date_dir,
year,
DOY,
user,
password,
sens_sel,
date_name,
gui,
verbose
)The function is called for its side effects
character array List of MODIS images to be downloaded for
the selected date (as returned from get_mod_filenames). Can be a single
image, or a list of images in case different tiles are needed!
character Folder where the hdfs are to be stored
character ["http"] Server to be used.
character Address of the http server for the selected product.
numeric Max number of retry attempts on download. If
download fails more that n_retries times consecutively, abort
logical if TRUE, download using aria2c
character array Sub-folder where the different images
can be found (element of the list returned from get_mod_dirs, used in case
of http download to generate the download addresses).
character Acquisition year of the images to be downloaded
character array Acquisition doys of the images to be downloaded
character Username for http download
character Password for http download
character ["terra" | "aqua"] Selected sensor.
character Date of acquisition of the images to be downloaded.
logical Indicates if on an interactive or non-interactive execution
(only influences where the log messages are sent).
logical If FALSE, suppress processing messages, Default: TRUE
Lorenzo Busetto, phD (2014-2017)
Luigi Ranghetti, phD (2015)