# Linux: common installation (script in /usr/bin,
# desktop entry in /usr/share/applications)
# (requires administrator permissions)
if (FALSE) {
# the administrator password is asked interactively
install_MODIStsp_launcher(sudo = TRUE)
}
# Linux: installation in a directory which does not require administrator
# permissions
if (FALSE) {
install_MODIStsp_launcher(bin_dir = "~/bin", desktop_dir = "~/Desktop")
}
# Windows: common installation
# (script in the Start Menu and shortcut on the desktop)
if (FALSE) {
install_MODIStsp_launcher()
}
Run the code above in your browser using DataLab